@@ -198,7 +198,7 @@ def distance_one_file (original_samples, output_path_original, file_context2, ge
 
 
 
-def analysis (project, genome, contexts, simContext, input_path, output_type='all', analysis='all', interdistance='96', exome=False, clustering_vaf=False, sortSims=True, extraction=False, correction=True, startProcess=1, endProcess=25, totalIterations=1000, calculateIMD=True, chrom_based=False, max_cpu=None, subClassify=False, sanger=True, TCGA=False, windowSize=10000000):
+def analysis (project, genome, contexts, simContext, input_path, output_type='all', analysis='all', interdistance='96', exome=False, clustering_vaf=False, sortSims=True, extraction=False, correction=True, startProcess=1, endProcess=25, totalIterations=1000, calculateIMD=True, chrom_based=False, max_cpu=None, subClassify=False, sanger=True, TCGA=False, windowSize=10000000, bedRanges=None):
 	'''
 	Organizes all of the data structures and calls all of the sub-functions. This is the main function called when running SigProfilerHotSpots.
 
@@ -536,7 +536,7 @@ def analysis (project, genome, contexts, simContext, input_path, output_type='al
 		sys.stderr.close()
 		sys.stderr = open(error_file, 'a')
 		print("Generating a rainfall plot for all samples...", end='')
-		plottingFunctions.rainfall(chrom_based, project, input_path, chrom_path, correction, windowSize)
+		plottingFunctions.rainfall(chrom_based, project, input_path, chrom_path, chromLengths, centromeres, correction, windowSize, bedRanges)
 		print("done")
 		print("Subclassification of clustered mutations has finished!")
 
